==> ejc-sealm-impl-3.0.0-20220309.001629-53-sources.jar: com/ejianc/business/sealm/bean/YywhzdEntity.java <==
package com.ejianc.business.sealm.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 用印维护字典
 * 
 * @author generator
 * 
 */
 @TableName("t_seal_yywhzd")
public class YywhzdEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="bdmc")
    private String bdmc; // 表单名称
    @TableField(value="bdlj")
    private String bdlj; // 表单链接
    @TableField(value="zkbm_id")
    private Long zkbmId; // 业务主控部门id
    @TableField(value="zkbm_name")
    private String zkbmName; // 业务主控部门名称
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="sf_yzsq")
    private Integer sfYzsq; // 是否从印章申请同步，默认是0(1:是，0：否)
    @TableField(value="begin_date")
    private Date beginDate; // 开始日期
    @TableField(value="end_date")
    private Date endDate; // 结束日期
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="update_user_name")
    private String updateUserName; // 修改人
    
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getBdmc() {
        return bdmc;
    }

    public void setBdmc(String bdmc) {
        this.bdmc = bdmc;
    }
    public String getBdlj() {
        return bdlj;
    }

    public void setBdlj(String bdlj) {
        this.bdlj = bdlj;
    }
    public Long getZkbmId() {
        return zkbmId;
    }

    public void setZkbmId(Long zkbmId) {
        this.zkbmId = zkbmId;
    }
    public String getZkbmName() {
        return zkbmName;
    }

    public void setZkbmName(String zkbmName) {
        this.zkbmName = zkbmName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getSfYzsq() {
        return sfYzsq;
    }

    public void setSfYzsq(Integer sfYzsq) {
        this.sfYzsq = sfYzsq;
    }
    public Date getBeginDate() {
        return beginDate;
    }

    public void setBeginDate(Date beginDate) {
        this.beginDate = beginDate;
    }
    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    
}

==> ejc-sealm-impl-3.0.0-20230923.074519-140-sources.jar: com/ejianc/business/sealm/bean/YywhzdEntity.java <==
package com.ejianc.business.sealm.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 用印维护字典
 * 
 * @author generator
 * 
 */
 @TableName("t_seal_yywhzd")
public class YywhzdEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="bdmc")
    private String bdmc; // 表单名称
    @TableField(value="bdlj")
    private String bdlj; // 表单链接
    @TableField(value="zkbm_id")
    private Long zkbmId; // 业务主控部门id
    @TableField(value="zkbm_name")
    private String zkbmName; // 业务主控部门名称
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="sf_yzsq")
    private Integer sfYzsq; // 是否从印章申请同步，默认是0(1:是，0：否)
    @TableField(value="begin_date")
    private Date beginDate; // 开始日期
    @TableField(value="end_date")
    private Date endDate; // 结束日期
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="update_user_name")
    private String updateUserName; // 修改人
    @TableField(value="czbm")
    private String czbm; // 参照编码
    @TableField(value="czid")
    private Long czid; // 参照id




    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getBdmc() {
        return bdmc;
    }

    public void setBdmc(String bdmc) {
        this.bdmc = bdmc;
    }
    public String getBdlj() {
        return bdlj;
    }

    public void setBdlj(String bdlj) {
        this.bdlj = bdlj;
    }
    public Long getZkbmId() {
        return zkbmId;
    }

    public void setZkbmId(Long zkbmId) {
        this.zkbmId = zkbmId;
    }
    public String getZkbmName() {
        return zkbmName;
    }

    public void setZkbmName(String zkbmName) {
        this.zkbmName = zkbmName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getSfYzsq() {
        return sfYzsq;
    }

    public void setSfYzsq(Integer sfYzsq) {
        this.sfYzsq = sfYzsq;
    }
    public Date getBeginDate() {
        return beginDate;
    }

    public void setBeginDate(Date beginDate) {
        this.beginDate = beginDate;
    }
    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }


    public String getCzbm() {
        return czbm;
    }

    public void setCzbm(String czbm) {
        this.czbm = czbm;
    }
    public Long getCzid() {
        return czid;
    }

    public void setCzid(Long czid) {
        this.czid = czid;
    }

}
